package eu.maiora.model

import eu.maiora.db.*
import org.jetbrains.exposed.sql.and
import java.time.LocalDate
import java.time.format.DateTimeFormatter

class ProdottiPrenotabiliRepositoryImpl : ProdottiPrenotabiliRepository {
    override suspend fun prodottiPrenotabiliByGiornoIdTurnoIdPuntoDistIdMod(giorno : String,
                                                                  idTurno : Long,
                                                                  idPuntoDistribuzione : Long,
                                                                  idModalita : Long): List<ProdottiPrenotabili> = suspendTransaction {
        // Cerca la lista di prodotti prenotabili
        val formatter = DateTimeFormatter.ofPattern("ddMMyyyy")
        val formattedDate = LocalDate.parse(giorno, formatter)

        ProdottiPrenotabiliDao.find { (ProdottiPrenotabiliTable.giorno eq formattedDate) and
                                    (ProdottiPrenotabiliTable.idTurno eq idTurno) and
                (ProdottiPrenotabiliTable.idPuntoDistribuzione eq idPuntoDistribuzione) and
                (ProdottiPrenotabiliTable.idModalita eq idModalita)}
            .toList() // Restituisce la lista dei prodotti prenotabili
            .map { prodottiPrenotabiliDaoToModel(it) } // Converte il DAO in un oggetto ProdottiPrenotabili

    }
}